@@ -35,12 +35,13 @@ from typing import (
     Optional,
     Type,
     List,
-    Union
+    Union,
+    cast
 )
 
 import requests.exceptions
 from grpclib.exceptions import StreamTerminatedError
-from pyee import AsyncIOEventEmitter  # type: ignore
+from pyee import AsyncIOEventEmitter
 
 from wechaty_puppet import (
     Puppet,
@@ -274,7 +275,7 @@ class Wechaty(AsyncIOEventEmitter):
         super().on(event, f)
         return self
 
-    def emit(self, event: str, *args: Any, **kwargs: Any) -> None:
+    def emit(self, event: str, *args: Any, **kwargs: Any) -> bool:
         """
         emit wechaty event
         :param event:
@@ -285,7 +286,7 @@ class Wechaty(AsyncIOEventEmitter):
         log.debug('emit() event <%s> <%s>',
                   [str(item) for item in args],
                   kwargs)
-        super().emit(event, *args, **kwargs)
+        return super().emit(event, *args, **kwargs)
 
     async def on_error(self, payload: EventErrorPayload) -> None:
         """
@@ -735,6 +736,8 @@ I suggest that you should follow the template code from: https://wechaty.readthe
         """
         user_id = self.puppet.self_id()
         user = self.ContactSelf.load(user_id)
+        # cast Contact -> ContactSelf
+        user = cast(ContactSelf, user)
         return user
 
     def self(self) -> ContactSelf:
